???+ note
    This Class is not meant to be instantiated directly, but rather accessed through the `cw.flows` Property on an
    instance of [Client](sync_client.md). For more details, see the [Guide](../../guides/cloud_works.md).

::: anaplan_sdk._async_clients._cw_flow._AsyncFlowClient
